searchData={"content_type":"text/markdown","items":[{"doc":"# OpentelemetryAbsinthe\nAn opentelemetry instrumentation library for Absinthe","ref":"OpentelemetryAbsinthe.html","title":"OpentelemetryAbsinthe","type":"module"},{"doc":"To start collecting traces just put `OpentelemetryAbsinthe.setup()` in your application start function.","ref":"OpentelemetryAbsinthe.html#module-usage","title":"Usage - OpentelemetryAbsinthe","type":"module"},{"doc":"OpentelemetryAbsinthe can be configured with the application environment\n```\nconfig :opentelemetry_absinthe,\n  trace_options: [\n    trace_request_query: false,\n    trace_response_error: true,\n    ...\n  ]\n```\nconfiguration can also be passed directly to the setup function\n```\nOpentelemetryAbsinthe.setup(\n  trace_request_query: false,\n  trace_response_error: true,\n  ...\n)\n```","ref":"OpentelemetryAbsinthe.html#module-configuration","title":"Configuration - OpentelemetryAbsinthe","type":"module"},{"doc":"* `span_name`(default: dynamic):\n\n    Either\n      - `:dynamic`: sets the span name dynamically, based on the operation name and type, as recommended by [opentelemetry](https://opentelemetry.io/docs/reference/specification/trace/semantic_conventions/instrumentation/graphql/). This will become the only supported option in the future.\n      - `String.t()`: *deprecated* the name of the span\n\n  * `trace_request_query`(default: true): attaches the graphql query as an attribute\n\n    **Important Note**: This is usually safe, since graphql queries are expected to be static. All dynamic data should be passed via graphql variables.\n    However some libraries(for example [dillonkearns/elm-graphql](https://github.com/dillonkearns/elm-graphql/issues/27) store the variables inline as a part of the query.\n    If you expect clients to send dynamic data as a part of the graphql query you should disable this.\n\n  * `trace_request_name`(default: true): attaches the graphql operation name when using batched queries as an attribute\n  * `trace_request_type`(default: true): attaches the graphql query type(query, mutation or subscription) as an attribute\n  * `trace_request_variables`(default: false): attaches the graphql variables as an attribute\n  * `trace_request_selections`(default: true): attaches the root fields queried as an attribute\n\n    For example given a query like:\n    ```\n      query($isbn: String!) {\n        book(isbn: $isbn) {\n          title\n          author {\n            name\n            age\n          }\n        }\n        reader {\n          name\n        }\n      }\n    ```\n    will result in a graphql.request.selections attribute with the value `[\"book\", \"reader\"]` being attached.\n    Note that aliased fields will use their unaliased name.\n\n  * `trace_response_result`(default: false): attaches the result returned by the server as an attribute\n  * `trace_response_errors`(default: false): attaches the errors returned by the server as an attribute\n  * `trace_subscriptions`(default: false): attaches to `[:absinthe, :subscription, :publish]` (`:start` and `:stop`)","ref":"OpentelemetryAbsinthe.html#module-configuration-options","title":"Configuration options - OpentelemetryAbsinthe","type":"module"},{"doc":"OpentelemetryAbsinthe exposes `telemetry` events which can be hooked into using `:telemetry.attach/4` or `:telemetry.attach_many/4`.\nThe events exposed are:\n\n- `[:opentelemetry_absinthe, :graphql, :handled]` for when a GraphQl query has been handled, the metadata and measurements are defined in `OpentelemetryAbsinthe.Instrumentation.graphql_handled_event_metadata()` and `OpentelemetryAbsinthe.Instrumentation.graphql_handled_event_measurements()`","ref":"OpentelemetryAbsinthe.html#module-telemetry","title":"Telemetry - OpentelemetryAbsinthe","type":"module"},{"doc":"","ref":"OpentelemetryAbsinthe.html#setup/1","title":"OpentelemetryAbsinthe.setup/1","type":"function"},{"doc":"OpenTelemetry-friendly alternatives of Absinthe.Resolution.Helpers functions\n\nSome of the standard absinthe resolution helpers, like `batch` or `async`,\nare not \"opentelemetry-friendly\": the resolvers, when invoked, lose the active span\nand break the trace propagation.\n\nThis module defines compatible alternatives that can be used in the same way,\nbut don't lose the trace information.","ref":"OpentelemetryAbsinthe.Helpers.html","title":"OpentelemetryAbsinthe.Helpers","type":"module"},{"doc":"Wrapper around the \"real\" batch function used by `batch_keep_span`\n\nTakes the passed span and sets it as the active one, then calls the original\nbatch function with the original parameter.","ref":"OpentelemetryAbsinthe.Helpers.html#batch_fun_wrapper/2","title":"OpentelemetryAbsinthe.Helpers.batch_fun_wrapper/2","type":"function"},{"doc":"Works like Absinthe.Resolution.Helpers.batch, but preserves the active span.\n\nThe function supplied to the `batch` helper is executed in a Task by Absinthe,\nwhich means that the erlang opentelemetry SDK would lose track of the currently\nactive span, because they are kept in a pdict.\n\nTo work around this, you can just replace `batch` with `batch_keep_span`,\nand the active span will be automatically passed and reset as the active one\ninside the batch function.","ref":"OpentelemetryAbsinthe.Helpers.html#batch_keep_span/3","title":"OpentelemetryAbsinthe.Helpers.batch_keep_span/3","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Helpers.html#batch_keep_span/4","title":"OpentelemetryAbsinthe.Helpers.batch_keep_span/4","type":"function"},{"doc":"Module for automatic instrumentation of Absinthe resolution.\n\nIt works by listening to [:absinthe, :execute, :operation, :start/:stop] telemetry events,\nwhich are emitted by Absinthe only since v1.5; therefore it won't work on previous versions.\n\n(you can still call `OpentelemetryAbsinthe.Instrumentation.setup()` in your application startup\ncode, it just won't do anything.)","ref":"OpentelemetryAbsinthe.Instrumentation.html","title":"OpentelemetryAbsinthe.Instrumentation","type":"module"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#default_config/0","title":"OpentelemetryAbsinthe.Instrumentation.default_config/0","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#handle_start/4","title":"OpentelemetryAbsinthe.Instrumentation.handle_start/4","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#handle_stop/4","title":"OpentelemetryAbsinthe.Instrumentation.handle_stop/4","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#setup/1","title":"OpentelemetryAbsinthe.Instrumentation.setup/1","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#span_ctx/1","title":"OpentelemetryAbsinthe.Instrumentation.span_ctx/1","type":"macro"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#span_ctx/2","title":"OpentelemetryAbsinthe.Instrumentation.span_ctx/2","type":"macro"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#teardown/0","title":"OpentelemetryAbsinthe.Instrumentation.teardown/0","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#t:graphql_handled_event_error/0","title":"OpentelemetryAbsinthe.Instrumentation.graphql_handled_event_error/0","type":"type"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#t:graphql_handled_event_measurements/0","title":"OpentelemetryAbsinthe.Instrumentation.graphql_handled_event_measurements/0","type":"type"},{"doc":"","ref":"OpentelemetryAbsinthe.Instrumentation.html#t:graphql_handled_event_metadata/0","title":"OpentelemetryAbsinthe.Instrumentation.graphql_handled_event_metadata/0","type":"type"},{"doc":"A helper module to allow integrators to add custom data to their context\n  which will then be added to the [:opentelemetry_absinthe, :graphql, :handled]\n  event","ref":"OpentelemetryAbsinthe.TelemetryMetadata.html","title":"OpentelemetryAbsinthe.TelemetryMetadata","type":"module"},{"doc":"","ref":"OpentelemetryAbsinthe.TelemetryMetadata.html#from_context/1","title":"OpentelemetryAbsinthe.TelemetryMetadata.from_context/1","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.TelemetryMetadata.html#update_context/2","title":"OpentelemetryAbsinthe.TelemetryMetadata.update_context/2","type":"function"},{"doc":"","ref":"OpentelemetryAbsinthe.TelemetryMetadata.html#t:absinthe_context/0","title":"OpentelemetryAbsinthe.TelemetryMetadata.absinthe_context/0","type":"type"},{"doc":"","ref":"OpentelemetryAbsinthe.TelemetryMetadata.html#t:telemetry_metadata/0","title":"OpentelemetryAbsinthe.TelemetryMetadata.telemetry_metadata/0","type":"type"},{"doc":"# OpentelemetryAbsinthe\n\nOpentelemetryAbsinthe is a [OpenTelemetry](https://opentelemetry.io) instrumentation library for [Absinthe](https://github.com/absinthe-graphql/absinthe).\n\nFull documentation is avaliable on [hexdocs](https://hexdocs.pm/opentelemetry_absinthe)","ref":"readme.html","title":"OpentelemetryAbsinthe","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}